@@ -7,12 +7,60 @@ from wordcloud import WordCloud
 from itertools import combinations
 from pandas.plotting import parallel_coordinates
 from sklearn.preprocessing import MinMaxScaler
+import operator as op
+from functools import reduce
 from warnings import filterwarnings
 filterwarnings('ignore')
 from math import pi
-from utils import *
 
 
+#####################################
+#       Color the background        #
+#####################################
+def bg(value, type='num', color='blue'):
+    value = str('{:,}'.format(value)) if type == 'num' else str(value)
+    return colored(' ' + value + ' ', color, attrs=['reverse', 'blink'])
+
+
+#####################################
+#          Show Annotations         #
+#####################################
+def show_annotation(dist, n=5, size=14, total=None):
+    sizes = []  # Get highest value in y
+    for p in dist.patches:
+        height = p.get_height()
+        sizes.append(height)
+
+        dist.text(p.get_x() + p.get_width() / 2.,          # At the center of each bar. (x-axis)
+                  height + n,                            # Set the (y-axis)
+                  '{:1.2f}%'.format(height * 100 / total) if total else '{}'.format(height),  # Set the text to be written
+                  ha='center', fontsize=size)
+    dist.set_ylim(0, max(sizes) * 1.15)  # set y limit based on highest heights
+
+
+#####################################
+#          Show Annotations         #
+#####################################
+def ncr(n, r):
+    r = min(r, n-r)
+    numer = reduce(op.mul, range(n, n-r, -1), 1)
+    denom = reduce(op.mul, range(1, r+1), 1)
+    return numer // denom
+
+#####################################
+#            Create Folder          #
+#####################################
+def create_folder(folder_name, verbose=True):
+    # Create visulizer Directory if don't exist
+    if not os.path.exists(os.path.join(os.getcwd(), folder_name)):
+        os.makedirs(os.path.join(os.getcwd(), folder_name))
+        if verbose: print("Directory " , folder_name ,  " Created ")
+    else:    
+        if verbose: print("Directory " , folder_name ,  " already exists")
+
+#####################################
+#            Visualizer             #
+#####################################
 class Visualizer:
     def __init__(self, df, target_col, num_cols=None, cat_cols=None, ignore_cols=None, problem_type='classification'):
         self.df           = df
@@ -21,7 +69,7 @@ class Visualizer:
         self.cat_cols     = cat_cols if cat_cols != None else list(df.select_dtypes('O').columns)
         self.ignore_cols  = ignore_cols
         self.problem_type = problem_type
-        self.version      = "0.0.6"
+        self.version      = "0.0.7"
 
         # Remove target_col from the numerical or categorical columns.
         if self.target_col in self.num_cols: self.num_cols.remove(self.target_col)
